gen

package
v0.0.0-...-abb4a95 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	RootID = vocab.IRI("https://example.com/~root")

	Root = &vocab.Actor{
		ID:                RootID,
		Type:              vocab.PersonType,
		Published:         defaultTime,
		Name:              vocab.DefaultNaturalLanguage("Rooty McRootface"),
		Summary:           vocab.DefaultNaturalLanguage("The base actor for the conformance test suite"),
		Content:           vocab.DefaultNaturalLanguage("<p>The base actor for the conformance test suite</p>"),
		URL:               vocab.Item(RootID),
		To:                publicAudience,
		Likes:             vocab.Likes.IRI(RootID),
		Shares:            vocab.Shares.IRI(RootID),
		Inbox:             vocab.Inbox.IRI(RootID),
		Outbox:            vocab.Outbox.IRI(RootID),
		Following:         vocab.Following.IRI(RootID),
		Followers:         vocab.Followers.IRI(RootID),
		Liked:             vocab.Liked.IRI(RootID),
		PreferredUsername: vocab.DefaultNaturalLanguage("root"),
	}
)
var ContentMap = buildContentMap()
var SetItemID = DefaultSetter

Functions

func DefaultSetter

func DefaultSetter(it vocab.Item)

func RandomActivity

func RandomActivity(ob vocab.Item, attrTo vocab.Item) vocab.Item

func RandomActor

func RandomActor(attrTo vocab.Item) vocab.Item

func RandomCollection

func RandomCollection(attrTo vocab.Item) vocab.CollectionInterface

func RandomImage

func RandomImage(mime vocab.MimeType, parent vocab.Item) vocab.Item

func RandomItem

func RandomItem(attrTo vocab.Item) vocab.Item

func RandomItemCollection

func RandomItemCollection(count int) vocab.ItemCollection
func RandomLink(attrTo vocab.Item) vocab.Item

func RandomObject

func RandomObject(attrTo vocab.Item) vocab.Item

func RandomObjectByType

func RandomObjectByType(attrTo vocab.Item, typ vocab.ActivityVocabularyType) vocab.Item

func RandomQuestion

func RandomQuestion(attrTo vocab.Item) vocab.Item

func RandomTag

func RandomTag(parent vocab.Item) vocab.Item

func SortItemCollectionByID

func SortItemCollectionByID(items vocab.ItemCollection)

Types

This section is empty.

Directories

Path Synopsis
Package names is copy/pasted from docker's code source The original can be found in package: "github.com/docker/docker/pkg/namesgenerator"
Package names is copy/pasted from docker's code source The original can be found in package: "github.com/docker/docker/pkg/namesgenerator"

Jump to